#!/bin/sh
# 
# Usage: ./mklinks.sh [RELEASEPATH] [BASEPATH]
# Create links in the RELEASEPATH directory that points
# to the real file in some other earlier release.
# The current directory is used by default.
# If BASEPATH is specified only links that have a corresponding
# match in BASEPATH are created
# 
<<RELEASEINFO>>

RELEASEPATH=${1-.}
BASEPATH=${2}

NUMLINKS=<<NUMLINKS>>
NCREATED=0
NCHECKED=0

if [ -z "${BASEPATH}" ]; then
	# BASEPATH was not set -- A full release is created in RELEASEPATH
	echo "Creating ${NUMLINKS} links to existing files"
else
	echo "Creating up to ${NUMLINKS} links in '${RELEASEPATH}' if they exist in '${BASEPATH}'"
fi

# Creates a link in RELEASEPATH
# $1 = The link to create (for example, /S000001/l.r.m.c.lib.g/S000001.l.r.m.c.lib.g_R1.fastq.gz)
# $2 = Relative path to reach the actual file 
#      (for example, ../../../1.0/S000001/l.r.m.c.lib.g/S000001.l.r.m.c.lib.g_R1.fastq.gz)
function createLink {
	NCHECKED=$(( ${NCHECKED} + 1 ))
	if [[ -z "${BASEPATH}" || -f "${BASEPATH}${1}" ]]; then
		echo "[${NCHECKED}/${NUMLINKS}] ${RELEASEPATH}${1}"
		ln -s $2 ${RELEASEPATH}$1
		NCREATED=$(( ${NCREATED} + 1 ))
	fi
}

<<SCRIPT>>

echo Done: ${NCREATED} links created

